==> rendition-9.10.0.tgz: package/dist_esm5/extra/Mermaid.js <==
import * as tslib_1 from "tslib";
import { mermaidAPI } from 'mermaid';
import * as React from 'react';
import uuid from 'uuid/v4';
import { Box } from '../components/Grid';
var Mermaid = (function (_super) {
    tslib_1.__extends(Mermaid, _super);
    function Mermaid(props) {
        var _this = _super.call(this, props) || this;
        _this.id = "rendition-mermaid-" + uuid();
        return _this;
    }
    Mermaid.prototype.componentDidMount = function () {
        this.renderSVG();
    };
    Mermaid.prototype.renderSVG = function () {
        var value = this.props.value;
        var renderArea = this.renderArea;
        if (!renderArea || !value) {
            return;
        }
        try {
            mermaidAPI.render(this.id, value, function (svgCode, bindFunctions) {
                renderArea.innerHTML = svgCode;
                bindFunctions(renderArea);
            });
        }
        catch (error) {
            renderArea.innerHTML = "Unable to parse input: " + error.message;
        }
    };
    Mermaid.prototype.componentDidUpdate = function (prevProps) {
        if (prevProps.value !== this.props.value) {
            this.renderSVG();
        }
    };
    Mermaid.prototype.render = function () {
        var _this = this;
        var _a = this.props, value = _a.value, props = tslib_1.__rest(_a, ["value"]);
        return (React.createElement(Box, tslib_1.__assign({}, props),
            React.createElement("div", { ref: function (element) { return (_this.renderArea = element); } })));
    };
    return Mermaid;
}(React.Component));
export { Mermaid };

==> rendition-11.12.1.tgz: package/dist_esm5/extra/Mermaid.js <==
import { __assign, __extends, __rest } from "tslib";
import { mermaidAPI } from 'mermaid';
import * as React from 'react';
import uuid from 'uuid/v4';
import { Box } from '../components/Grid';
var Mermaid = (function (_super) {
    __extends(Mermaid, _super);
    function Mermaid(props) {
        var _this = _super.call(this, props) || this;
        _this.id = "rendition-mermaid-" + uuid();
        return _this;
    }
    Mermaid.prototype.componentDidMount = function () {
        this.renderSVG();
    };
    Mermaid.prototype.renderSVG = function () {
        var value = this.props.value;
        var renderArea = this.renderArea;
        if (!renderArea || !value) {
            return;
        }
        try {
            mermaidAPI.render(this.id, value, function (svgCode, bindFunctions) {
                renderArea.innerHTML = svgCode;
                bindFunctions(renderArea);
            });
        }
        catch (error) {
            renderArea.innerHTML = "Unable to parse input: " + error.message;
        }
    };
    Mermaid.prototype.componentDidUpdate = function (prevProps) {
        if (prevProps.value !== this.props.value) {
            this.renderSVG();
        }
    };
    Mermaid.prototype.render = function () {
        var _this = this;
        var _a = this.props, value = _a.value, props = __rest(_a, ["value"]);
        return (React.createElement(Box, __assign({}, props),
            React.createElement("div", { ref: function (element) { return (_this.renderArea = element); } })));
    };
    return Mermaid;
}(React.Component));
export { Mermaid };
